@@ -67,7 +67,7 @@ INVALID_IMAGE_NAME = "INVALID-IMAGE-NAME"
 @rewrite_module
 @dataclass(frozen=True)
 class Resources:
-    memory_mb: int
+    memory: int
     cpu: float
     gpu: Optional[int] = None
     gpu_model: Optional[str] = None
@@ -75,6 +75,10 @@ class Resources:
     tpu_type: Optional[str] = None
     tpu_software_version: Optional[str] = None
 
+    @property
+    def memory_mb(self) -> int:
+        return self.memory // 2**20
+
 
 @rewrite_module
 class JobStatus(str, enum.Enum):
@@ -255,10 +259,20 @@ class JobDescription:
 @dataclass(frozen=True)
 class JobTelemetry:
     cpu: float
-    memory: float
+    memory_bytes: int
     timestamp: float
     gpu_duty_cycle: Optional[int] = None
-    gpu_memory: Optional[float] = None
+    gpu_memory_bytes: Optional[int] = None
+
+    @property
+    def memory(self) -> float:
+        return self.memory_bytes / 2**20
+
+    @property
+    def gpu_memory(self) -> Optional[float]:
+        if self.gpu_memory_bytes is None:
+            return None
+        return self.gpu_memory_bytes / 2**20
 
 
 @rewrite_module
@@ -285,6 +299,10 @@ class StdStream:
         if msg.type in (WSMsgType.CLOSE, WSMsgType.CLOSING, WSMsgType.CLOSED):
             self._closing = True
             return None
+        if msg.type == aiohttp.WSMsgType.ERROR:
+            raise self._ws.exception()  # type: ignore
+        if msg.type != aiohttp.WSMsgType.BINARY:
+            raise RuntimeError(f"Incorrecr WebSocket message: {msg!r}")
         if msg.data[0] == 3:
             try:
                 details = json.loads(msg.data[1:])
@@ -552,8 +570,13 @@ class Jobs(metaclass=NoPublicConstructor):
             heartbeat=30,
         ) as ws:
             async for msg in ws:
-                if msg.data:
-                    yield msg.data
+                if msg.type == aiohttp.WSMsgType.BINARY:
+                    if msg.data:
+                        yield msg.data
+                elif msg.type == aiohttp.WSMsgType.ERROR:
+                    raise ws.exception()  # type: ignore
+                else:
+                    raise RuntimeError(f"Incorrecr WebSocket message: {msg!r}")
 
     async def status(self, id: str) -> JobDescription:
         url = self._config.api_url / "jobs" / id
@@ -575,6 +598,10 @@ class Jobs(metaclass=NoPublicConstructor):
                     if msg.type == aiohttp.WSMsgType.TEXT:
                         yield _job_telemetry_from_api(msg.json())
                         received_any = True
+                    elif msg.type == aiohttp.WSMsgType.ERROR:
+                        raise ws.exception()  # type: ignore
+                    else:
+                        raise RuntimeError(f"Incorrecr WebSocket message: {msg!r}")
             if not received_any:
                 raise ValueError(f"Job is not running. Job Id = {id}")
         except WSServerHandshakeError as e:
@@ -691,9 +718,13 @@ class Jobs(metaclass=NoPublicConstructor):
         self, ws: aiohttp.ClientWebSocketResponse, writer: asyncio.StreamWriter
     ) -> None:
         async for msg in ws:
-            assert msg.type == aiohttp.WSMsgType.BINARY
-            writer.write(msg.data)
-            await writer.drain()
+            if msg.type == aiohttp.WSMsgType.BINARY:
+                writer.write(msg.data)
+                await writer.drain()
+            elif msg.type == aiohttp.WSMsgType.ERROR:
+                raise ws.exception()  # type: ignore
+            else:
+                raise RuntimeError(f"Incorrecr WebSocket message: {msg!r}")
         writer.close()
         await writer.wait_closed()
 
@@ -830,7 +861,7 @@ def _raise_for_invalid_commit_chunk(obj: Dict[str, Any], expect_started: bool) -
 
 def _resources_to_api(resources: Resources) -> Dict[str, Any]:
     value: Dict[str, Any] = {
-        "memory_mb": resources.memory_mb,
+        "memory": resources.memory,
         "cpu": resources.cpu,
         "shm": resources.shm,
     }
@@ -853,7 +884,7 @@ def _resources_from_api(data: Dict[str, Any]) -> Resources:
         tpu_type = tpu["type"]
         tpu_software_version = tpu["software_version"]
     return Resources(
-        memory_mb=data["memory_mb"],
+        memory=data["memory"],
         cpu=data["cpu"],
         shm=data.get("shm", True),
         gpu=data.get("gpu", None),
@@ -1085,10 +1116,10 @@ def _job_to_api(
 def _job_telemetry_from_api(value: Dict[str, Any]) -> JobTelemetry:
     return JobTelemetry(
         cpu=value["cpu"],
-        memory=value["memory"],
+        memory_bytes=value["memory_bytes"],
         timestamp=value["timestamp"],
         gpu_duty_cycle=value.get("gpu_duty_cycle"),
-        gpu_memory=value.get("gpu_memory"),
+        gpu_memory_bytes=value.get("gpu_memory_bytes"),
     )
 
 
