@@ -66,9 +66,9 @@ async def test_list_clusters_with_cloud_provider(
                             "max_size": 2,
                             "idle_size": 1,
                             "available_cpu": 7,
-                            "available_memory_mb": 46080,
+                            "available_memory": 46080 * 2**20,
                             "disk_type": "ssd",
-                            "disk_size_gb": 150,
+                            "disk_size": 150 * 2**30,
                             "gpu": 1,
                             "gpu_model": "nvidia-tesla-k80",
                             "is_preemptible": True,
@@ -78,15 +78,15 @@ async def test_list_clusters_with_cloud_provider(
                             "min_size": 1,
                             "max_size": 2,
                             "available_cpu": 7,
-                            "available_memory_mb": 46080,
-                            "disk_size_gb": 150,
+                            "available_memory": 46080 * 2**20,
+                            "disk_size": 150 * 2**30,
                         },
                     ],
                     "storage": {
                         "description": "Filestore",
                         "instances": [
-                            {"size_mb": 1024},
-                            {"name": "org", "size_mb": 1024},
+                            {"size": 1024 * 2**20},
+                            {"name": "org", "size": 1024 * 2**20},
                         ],
                     },
                 },
@@ -102,13 +102,13 @@ async def test_list_clusters_with_cloud_provider(
                             "max_size": 2,
                             "machine_type": "n1-highmem-8",
                             "available_cpu": 7,
-                            "available_memory_mb": 46080,
-                            "disk_size_gb": 150,
+                            "available_memory": 46080 * 2**20,
+                            "disk_size": 150 * 2**30,
                         },
                     ],
                     "storage": {
                         "description": "NFS",
-                        "instances": [{"size_mb": 1024}],
+                        "instances": [{"size": 1024 * 2**20}],
                     },
                 },
             },
@@ -151,9 +151,9 @@ async def test_list_clusters_with_cloud_provider(
                             idle_size=1,
                             machine_type="n1-highmem-8",
                             available_cpu=7.0,
-                            available_memory_mb=46080,
+                            available_memory=46080 * 2**20,
                             disk_type="ssd",
-                            disk_size_gb=150,
+                            disk_size=150 * 2**30,
                             gpu=1,
                             gpu_model="nvidia-tesla-k80",
                             is_preemptible=True,
@@ -163,15 +163,15 @@ async def test_list_clusters_with_cloud_provider(
                             max_size=2,
                             machine_type="n1-highmem-8",
                             available_cpu=7.0,
-                            available_memory_mb=46080,
-                            disk_size_gb=150,
+                            available_memory=46080 * 2**20,
+                            disk_size=150 * 2**30,
                         ),
                     ],
                     storage=_Storage(
                         description="Filestore",
                         instances=[
-                            _StorageInstance(size_mb=1024),
-                            _StorageInstance(name="org", size_mb=1024),
+                            _StorageInstance(size=1024 * 2**20),
+                            _StorageInstance(name="org", size=1024 * 2**20),
                         ],
                     ),
                 ),
@@ -188,14 +188,14 @@ async def test_list_clusters_with_cloud_provider(
                             min_size=2,
                             max_size=2,
                             machine_type="n1-highmem-8",
-                            disk_size_gb=150,
+                            disk_size=150 * 2**30,
                             available_cpu=7.0,
-                            available_memory_mb=46080,
+                            available_memory=46080 * 2**20,
                         ),
                     ],
                     storage=_Storage(
                         description="NFS",
-                        instances=[_StorageInstance(size_mb=1024)],
+                        instances=[_StorageInstance(size=1024 * 2**20)],
                     ),
                 ),
             ),
@@ -266,7 +266,7 @@ async def test_add_cluster(
         ],
         "storage": {
             "id": "premium",  # id of the GCP storage template
-            "instances": [{"size_mb": 1024}],
+            "instances": [{"size": 1024 * 2**20}],
         },
     }
 
@@ -351,7 +351,7 @@ async def test_update_cluster_resource_presets(
                 "name": "cpu-micro",
                 "credits_per_hour": "10",
                 "cpu": 0.1,
-                "memory_mb": 100,
+                "memory": 100 * 2**20,
                 "scheduler_enabled": False,
                 "preemptible_node": False,
             },
@@ -359,7 +359,7 @@ async def test_update_cluster_resource_presets(
                 "name": "cpu-micro-p",
                 "credits_per_hour": "10",
                 "cpu": 0.1,
-                "memory_mb": 100,
+                "memory": 100 * 2**20,
                 "scheduler_enabled": True,
                 "preemptible_node": True,
             },
@@ -367,7 +367,7 @@ async def test_update_cluster_resource_presets(
                 "name": "gpu-micro",
                 "credits_per_hour": "10",
                 "cpu": 0.2,
-                "memory_mb": 200,
+                "memory": 200 * 2**20,
                 "gpu": 1,
                 "gpu_model": "nvidia-tesla-k80",
                 "scheduler_enabled": False,
@@ -377,7 +377,7 @@ async def test_update_cluster_resource_presets(
                 "name": "tpu-micro",
                 "credits_per_hour": "10",
                 "cpu": 0.3,
-                "memory_mb": 300,
+                "memory": 300 * 2**20,
                 "tpu": {"type": "v2-8", "software_version": "1.14"},
                 "scheduler_enabled": False,
                 "preemptible_node": False,
@@ -398,26 +398,26 @@ async def test_update_cluster_resource_presets(
             "my_cluster",
             {
                 "cpu-micro": Preset(
-                    credits_per_hour=Decimal("10"), cpu=0.1, memory_mb=100
+                    credits_per_hour=Decimal("10"), cpu=0.1, memory=100 * 2**20
                 ),
                 "cpu-micro-p": Preset(
                     credits_per_hour=Decimal("10"),
                     cpu=0.1,
-                    memory_mb=100,
+                    memory=100 * 2**20,
                     scheduler_enabled=True,
                     preemptible_node=True,
                 ),
                 "gpu-micro": Preset(
                     credits_per_hour=Decimal("10"),
                     cpu=0.2,
-                    memory_mb=200,
+                    memory=200 * 2**20,
                     gpu=1,
                     gpu_model="nvidia-tesla-k80",
                 ),
                 "tpu-micro": Preset(
                     credits_per_hour=Decimal("10"),
                     cpu=0.3,
-                    memory_mb=300,
+                    memory=300 * 2**20,
                     tpu_type="v2-8",
                     tpu_software_version="1.14",
                 ),
